3. CpGtools Release history — CpGtools documentation

# 3. CpGtools Release history

## 3.1. Version 1.0.8

Fix bug for beta_tSNE.py and beta_PCA.py when sample IDs are number.

## 3.2. Version 1.0.7

Add “CpG_density_gene_centered.py” on 03/11/2020

## 3.3. Version 1.0.2

Add ‘beta_tSNE.py’ on 07/15/2019

  This program performs t-SNE (t-Distributed Stochastic Neighbor Embedding) analysis for samples.

## 3.4. Version 1.0.1

Add ‘CpG_anno_position.py’ on 07/07/2019

  This program annotates CpG by its genomic position using prebuilt or user-provided annotation files.

## 3.5. Version 1.0.0

> Initial release